@@ -4,7 +4,7 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject.h>		// For Swarm
+#import <objectbase.h>		// For Swarm
 #import <simtools.h>		// For probes
 #import <analysis.h>		// For EZGraph
 #import <activity.h>		// For swarmActivity
