@@ -5,7 +5,7 @@
 #ifndef _SSPOP_H
 #define _SSPOP_H
 
-#import <swarmobject.h>
+#import <objectbase.h>
 
 #import "Population.h"		// Population protocol
 
